summaryrefslogtreecommitdiffstats
path: root/ui/recent.h
diff options
context:
space:
mode:
Diffstat (limited to 'ui/recent.h')
-rw-r--r--ui/recent.h146
1 files changed, 91 insertions, 55 deletions
diff --git a/ui/recent.h b/ui/recent.h
index 99918ea4..07163dbd 100644
--- a/ui/recent.h
+++ b/ui/recent.h
@@ -41,10 +41,8 @@ extern "C" {
#define RECENT_KEY_REMOTE_HOST "recent.remote_host"
typedef struct _col_width_data {
- gint cfmt;
- gchar *cfield;
- gint width;
- gchar xalign;
+ int width;
+ char xalign;
} col_width_data;
/** Defines used in col_width_data.xalign */
@@ -102,6 +100,12 @@ typedef enum {
} bytes_show_type;
typedef enum {
+ FOLLOW_DELTA_NONE,
+ FOLLOW_DELTA_TURN,
+ FOLLOW_DELTA_ALL
+} follow_delta_type;
+
+typedef enum {
DecodeAsNone,
DecodeAsBASE64,
DecodeAsCompressed,
@@ -113,53 +117,59 @@ typedef enum {
/** Recent settings. */
typedef struct recent_settings_tag {
- gboolean main_toolbar_show;
- gboolean filter_toolbar_show;
- gboolean wireless_toolbar_show;
- gboolean packet_list_show;
- gboolean tree_view_show;
- gboolean byte_view_show;
- gboolean packet_diagram_show;
- gboolean statusbar_show;
- gboolean packet_list_colorize;
- gboolean capture_auto_scroll;
+ bool main_toolbar_show;
+ bool filter_toolbar_show;
+ bool wireless_toolbar_show;
+ bool packet_list_show;
+ bool tree_view_show;
+ bool byte_view_show;
+ bool packet_diagram_show;
+ bool statusbar_show;
+ bool packet_list_colorize;
+ bool capture_auto_scroll;
ts_type gui_time_format;
- gint gui_time_precision;
+ int gui_time_precision;
ts_seconds_type gui_seconds_format;
- gint gui_zoom_level;
+ int gui_zoom_level;
bytes_view_type gui_bytes_view;
bytes_encoding_type gui_bytes_encoding;
- gboolean gui_packet_diagram_field_values;
- gboolean gui_allow_hover_selection;
+ bool gui_packet_diagram_field_values;
+ bool gui_allow_hover_selection;
search_in_type gui_search_in;
search_char_set_type gui_search_char_set;
- gboolean gui_search_case_sensitive;
+ bool gui_search_case_sensitive;
+ bool gui_search_reverse_dir;
+ bool gui_search_multiple_occurs;
search_type_type gui_search_type;
bytes_show_type gui_follow_show;
+ follow_delta_type gui_follow_delta;
bytes_decode_type gui_show_bytes_decode;
bytes_show_type gui_show_bytes_show;
- gint gui_geometry_main_x;
- gint gui_geometry_main_y;
- gint gui_geometry_main_width;
- gint gui_geometry_main_height;
-
- gboolean gui_geometry_main_maximized;
- gboolean gui_geometry_leftalign_actions;
-
- gint gui_geometry_main_upper_pane;
- gint gui_geometry_main_lower_pane;
- gint gui_geometry_wlan_stats_pane;
- gboolean privs_warn_if_elevated;
- gboolean sys_warn_if_no_capture;
+ int gui_geometry_main_x;
+ int gui_geometry_main_y;
+ int gui_geometry_main_width;
+ int gui_geometry_main_height;
+
+ bool gui_geometry_main_maximized;
+ bool gui_geometry_leftalign_actions;
+
+ int gui_geometry_main_upper_pane;
+ int gui_geometry_main_lower_pane;
+ char *gui_geometry_main;
+ char *gui_geometry_main_master_split;
+ char *gui_geometry_main_extra_split;
+ bool privs_warn_if_elevated;
+ bool sys_warn_if_no_capture;
GList *col_width_list; /* column widths */
GList *conversation_tabs; /* enabled conversation dialog tabs */
GList *conversation_tabs_columns; /* save the columns for conversation dialogs */
GList *endpoint_tabs; /* enabled endpoint dialog tabs */
GList *endpoint_tabs_columns; /* save the columns for endpoint dialogs */
- gchar *gui_fileopen_remembered_dir; /* folder of last capture loaded in File Open dialog */
- gboolean gui_rlc_use_pdus_from_mac;
+ int gui_profile_switch_check_count; /* number of packets / events to check for automatic profile switching */
+ char *gui_fileopen_remembered_dir; /* folder of last capture loaded in File Open dialog */
+ bool gui_rlc_use_pdus_from_mac;
GList *custom_colors;
GList *gui_additional_toolbars;
GList *interface_toolbars;
@@ -176,39 +186,39 @@ extern void recent_cleanup(void);
/** Write recent_common settings file.
*
- * @return TRUE if succeeded, FALSE if failed
+ * @return true if succeeded, false if failed
*/
-extern gboolean write_recent(void);
+extern bool write_recent(void);
/** Write profile recent settings file.
*
- * @return TRUE if succeeded, FALSE if failed
+ * @return true if succeeded, false if failed
*/
-extern gboolean write_profile_recent(void);
+extern bool write_profile_recent(void);
/** Read recent settings file (static part).
*
* @param rf_path_return path to recent file if function failed
* @param rf_errno_return if failed
- * @return TRUE if succeeded, FALSE if failed (check parameters for reason).
+ * @return true if succeeded, false if failed (check parameters for reason).
*/
-extern gboolean recent_read_static(char **rf_path_return, int *rf_errno_return);
+extern bool recent_read_static(char **rf_path_return, int *rf_errno_return);
/** Read profile recent settings file (static part).
*
* @param rf_path_return path to recent file if function failed
* @param rf_errno_return if failed
- * @return TRUE if succeeded, FALSE if failed (check parameters for reason).
+ * @return true if succeeded, false if failed (check parameters for reason).
*/
-extern gboolean recent_read_profile_static(char **rf_path_return, int *rf_errno_return);
+extern bool recent_read_profile_static(char **rf_path_return, int *rf_errno_return);
/** Read recent settings file (dynamic part).
*
* @param rf_path_return path to recent file if function failed
* @param rf_errno_return if failed
- * @return TRUE if succeeded, FALSE if failed (check parameters for reason).
+ * @return true if succeeded, false if failed (check parameters for reason).
*/
-extern gboolean recent_read_dynamic(char **rf_path_return, int *rf_errno_return);
+extern bool recent_read_dynamic(char **rf_path_return, int *rf_errno_return);
/**
* Given a -o command line string, parse it and set the recent value in
@@ -221,44 +231,70 @@ extern gboolean recent_read_dynamic(char **rf_path_return, int *rf_errno_return)
*/
extern int recent_set_arg(char *prefarg);
+/** Free the recent settings list of column width information
+ *
+ * @param rs the recent settings (currently a global)
+ */
+extern void recent_free_column_width_info(recent_settings_t *rs);
+
+/** Insert an entry in the recent column width setting for
+ * the given column, which should have been just added to
+ * the column list preference. (This keeps them in sync.)
+ *
+ * @param col column number
+ */
+extern void recent_insert_column(int col);
+
+/** Remove an entry in the recent column width setting for
+ * the given column, which should have been just removed to
+ * the column list preference. (This keeps them in sync.)
+ *
+ * @param col column number
+ */
+extern void recent_remove_column(int col);
+
/** Get the column width for the given column
*
* @param col column number
*/
-extern gint recent_get_column_width(gint col);
+extern int recent_get_column_width(int col);
/** Set the column width for the given column
*
* @param col column number
* @param width column width
*/
-extern void recent_set_column_width(gint col, gint width);
+extern void recent_set_column_width(int col, int width);
/** Get the column xalign for the given column
*
* @param col column number
*/
-extern gchar recent_get_column_xalign(gint col);
+extern char recent_get_column_xalign(int col);
/** Set the column xalign for the given column
*
* @param col column number
* @param xalign column alignment
*/
-extern void recent_set_column_xalign(gint col, gchar xalign);
+extern void recent_set_column_xalign(int col, char xalign);
/* save the window and its current geometry into the geometry hashtable */
-extern void window_geom_save(const gchar *name, window_geometry_t *geom);
+extern void window_geom_save(const char *name, window_geometry_t *geom);
/* load the desired geometry for this window from the geometry hashtable */
-extern gboolean window_geom_load(const gchar *name, window_geometry_t *geom);
+extern bool window_geom_load(const char *name, window_geometry_t *geom);
+
+extern void window_splitter_save(const char *name, const char *splitter_state);
+
+extern const char * window_splitter_load(const char *name);
/**
* Returns a list of recent capture filters.
*
* @param ifname interface name; NULL refers to the global list.
*/
-extern GList *recent_get_cfilter_list(const gchar *ifname);
+extern GList *recent_get_cfilter_list(const char *ifname);
/**
* Add a capture filter to the global recent capture filter list or
@@ -267,7 +303,7 @@ extern GList *recent_get_cfilter_list(const gchar *ifname);
* @param ifname interface name; NULL refers to the global list.
* @param s text of capture filter
*/
-extern void recent_add_cfilter(const gchar *ifname, const gchar *s);
+extern void recent_add_cfilter(const char *ifname, const char *s);
/**
* Get the value of an entry for a remote host from the remote host list.
@@ -276,7 +312,7 @@ extern void recent_add_cfilter(const gchar *ifname, const gchar *s);
*
* @return pointer to the entry for the remote host.
*/
-extern struct remote_host *recent_get_remote_host(const gchar *host);
+extern struct remote_host *recent_get_remote_host(const char *host);
/**
* Get the number of entries of the remote host list.
@@ -292,7 +328,7 @@ extern int recent_get_remote_host_list_size(void);
* @param func function to be called
* @param user_data argument to pass as user data to the function
*/
-extern void recent_remote_host_list_foreach(GHFunc func, gpointer user_data);
+extern void recent_remote_host_list_foreach(GFunc func, void *user_data);
/**
* Free all entries of the remote host list.
@@ -305,7 +341,7 @@ extern void recent_free_remote_host_list(void);
* @param host Key of the entry
* @param rh Value of the entry
*/
-extern void recent_add_remote_host(gchar *host, struct remote_host *rh);
+extern void recent_add_remote_host(char *host, struct remote_host *rh);
#ifdef __cplusplus
}